# Python: TSmart

[![GitHub Release][releases-shield]][releases]
[![Python Versions][python-versions-shield]][pypi]
![Project Stage][project-stage-shield]
![Project Maintenance][maintenance-shield]
[![License][license-shield]](LICENSE.md)

[![Build Status][build-shield]][build]
[![Code Coverage][codecov-shield]][codecov]
[![Code Smells][code-smells]][sonarcloud]

Asynchronous Python client for TSmart.

## About

This package allows you to fetch data from your TSmart Immersion Heater.

## Installation

```bash
pip install aiotsmart
```

## Usage

```python
from aiotsmart.tsmart import TSmartClient, TSmartDiscovery, Mode

# Discovery
discovery = TSmartDiscovery()
devices = await discovery.discover()
print(devices)

# Configuration
client = TSmartClient(YOUR_IP)
configuration = await client.configuration_read()
print(configuration)

# Status
client = TSmartClient(YOUR_IP)
status = await client.control_read()
print(status)

# Set
client = TSmartClient(YOUR_IP)
await client.control_write(power=True, mode=Mode.MANUAL, setpoint=30)
```

## Changelog & Releases

This repository keeps a change log using [GitHub's releases][releases]
functionality. The format of the log is based on
[Keep a Changelog][keepchangelog].

Releases are based on [Semantic Versioning][semver], and use the format
of `MAJOR.MINOR.PATCH`. In a nutshell, the version will be incremented
based on the following:

- `MAJOR`: Incompatible or major changes.
- `MINOR`: Backwards-compatible new features and enhancements.
- `PATCH`: Backwards-compatible bugfixes and package updates.

## Contributing

This is an active open-source project. We are always open to people who want to
use the code or contribute to it.

We've set up a separate document for our
[contribution guidelines](.github/CONTRIBUTING.md).

Thank you for being involved! :heart_eyes:

## Setting up development environment

This Python project is fully managed using the [UV][uv] package manager. UV is a fast Python package manager that replaces pip, pip-tools, and virtualenv. It also relies on the use of NodeJS for certain checks during development.

You need at least:

- Python 3.11+
- [UV][uv-install]

To install all packages, including all development requirements:

```bash
uv sync --all-extras
```

As this repository uses the [pre-commit][pre-commit] framework, all changes
are linted and tested with each commit. You can run all checks and tests
manually, using the following command:

```bash
uv run pre-commit run --all-files
```

To run just the Python tests:

```bash
uv run pytest
```

## Authors & contributors

The content is by [Andrew Jackson][andrew-codechimp].

For a full list of all authors and contributors,
check [the contributor's page][contributors].

## Disclaimer

This library is in no way approved, endorsed or supported by Tesla UK Ltd.

## Acknowledgements

<details>
    <summary>This library builds upon the great work by Paul Warren</summary>
    MIT License

    Copyright (c) 2023 Paul Warren

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.

</details>

## License

MIT License

Copyright (c) 2025 Andrew Jackson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[build-shield]: https://github.com/andrew-codechimp/python-tsmart/actions/workflows/tests.yaml/badge.svg
[build]: https://github.com/andrew-codechimp/python-tsmart/actions
[code-smells]: https://sonarcloud.io/api/project_badges/measure?project=andrew-codechimp_python-tsmart&metric=code_smells
[codecov-shield]: https://codecov.io/gh/andrew-codechimp/python-tsmart/branch/main/graph/badge.svg
[codecov]: https://codecov.io/gh/andrew-codechimp/python-tsmart
[commits-shield]: https://img.shields.io/github/commit-activity/y/andrew-codechimp/python-tsmart.svg
[commits]: https://github.com/andrew-codechimp/python-tsmart/commits/master
[contributors]: https://github.com/andrew-codechimp/python-tsmart/graphs/contributors
[andrew-codechimp]: https://github.com/andrew-codechimp
[keepchangelog]: http://keepachangelog.com/en/1.0.0/
[license-shield]: https://img.shields.io/github/license/andrew-codechimp/python-tsmart.svg
[maintenance-shield]: https://img.shields.io/maintenance/yes/2026.svg
[uv-install]: https://github.com/astral-sh/uv#installation
[uv]: https://github.com/astral-sh/uv
[pre-commit]: https://pre-commit.com/
[project-stage-shield]: https://img.shields.io/badge/project%20stage-stable-green.svg
[python-versions-shield]: https://img.shields.io/pypi/pyversions/aiotsmart
[releases-shield]: https://img.shields.io/github/release/andrew-codechimp/python-tsmart.svg
[releases]: https://github.com/andrew-codechimp/python-tsmart/releases
[semver]: http://semver.org/spec/v2.0.0.html
[sonarcloud]: https://sonarcloud.io/summary/new_code?id=andrew-codechimp_python-tsmart
[pypi]: https://pypi.org/project/aiotsmart/
